@@ -1,17 +1,17 @@
 <?php
-require_once("../xajax.inc.php");
+require_once("../xajax_core/xajax.inc.php");
 
 function addEvent($sId,$sCode)
 {
 	$objResponse = new xajaxResponse();
 	$objResponse->addEvent($sId, "onclick", $sCode);
-	return $objResponse->getXML();
+	return $objResponse;
 }
 
 $xajax = new xajax();
-//$xajax->debugOn();
+//$xajax->setFlag("debug", true);
 $xajax->registerFunction("addEvent");
-$xajax->processRequests();
+$xajax->processRequest();
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
         "http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-transitional.dtd">
