@@ -1,18 +1,18 @@
 <?php
-require_once("../xajax.inc.php");
+require_once("../xajax_core/xajax.inc.php");
 
 function testForm($formData)
 {
 	$objResponse = new xajaxResponse();
-	$objResponse->addAlert("formData: " . print_r($formData, true));
-	$objResponse->addAssign("submittedDiv", "innerHTML", nl2br(print_r($formData, true)));
-	return $objResponse->getXML();
+	$objResponse->alert("formData: " . print_r($formData, true));
+	$objResponse->assign("submittedDiv", "innerHTML", nl2br(print_r($formData, true)));
+	return $objResponse;
 }
 
 $xajax = new xajax();
-//$xajax->debugOn();
+//$xajax->setFlag("debug", true);
 $xajax->registerFunction("testForm");
-$xajax->processRequests();
+$xajax->processRequest();
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
         "http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-transitional.dtd">
