@@ -1,17 +1,18 @@
 <?php
-require_once("../xajax.inc.php");
+
+require_once("../xajax_core/xajax.inc.php");
 
 function includeScript($sFilename)
 {
 	$objResponse = new xajaxResponse();
-	$objResponse->addIncludeScript($sFilename);
-	return $objResponse->getXML();
+	$objResponse->includeScript($sFilename);
+	return $objResponse;
 }
 
 $xajax = new xajax();
-//$xajax->debugOn();
+//$xajax->setFlag("debug", true);
 $xajax->registerFunction("includeScript");
-$xajax->processRequests();
+$xajax->processRequest();
 ?>
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
         "http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-transitional.dtd">
