@@ -2,7 +2,7 @@
 function myExternalFunction()
 {
 	$objResponse = new xajaxResponse();
-	$objResponse->addAlert('External function successfully included and executed');
+	$objResponse->alert('External function successfully included and executed');
 	return $objResponse;
 }
 
@@ -11,7 +11,7 @@ class myExternalClass
 	function myMethod()	// static (can't hardwire that in because of PHP 4)
 	{
 		$objResponse = new xajaxResponse();
-		$objResponse->addAlert('External class successfully included and method executed');
+		$objResponse->alert('External class successfully included and method executed');
 		return $objResponse;
 	}
 }
